package com.vass.gex;



import java.io.File;
import java.io.IOException;

import org.apache.log4j.Logger;

import com.appiancorp.suiteapi.common.Name;
import com.appiancorp.suiteapi.common.exceptions.InvalidVersionException;
import com.appiancorp.suiteapi.common.exceptions.PrivilegeException;
import com.appiancorp.suiteapi.common.exceptions.StorageLimitException;
import com.appiancorp.suiteapi.content.ContentConstants;
import com.appiancorp.suiteapi.content.ContentService;
import com.appiancorp.suiteapi.content.exceptions.DuplicateUuidException;
import com.appiancorp.suiteapi.content.exceptions.InsufficientNameUniquenessException;
import com.appiancorp.suiteapi.content.exceptions.InvalidContentException;
import com.appiancorp.suiteapi.knowledge.DocumentDataType;
import com.appiancorp.suiteapi.knowledge.FolderDataType;
import com.appiancorp.suiteapi.process.exceptions.SmartServiceException;
import com.appiancorp.suiteapi.process.framework.AppianSmartService;
import com.appiancorp.suiteapi.process.framework.Input;
import com.appiancorp.suiteapi.process.framework.Required;
import com.appiancorp.suiteapi.process.framework.SmartServiceContext;
import com.appiancorp.suiteapi.process.palette.PaletteCategoryConstants;
import com.appiancorp.suiteapi.process.palette.PaletteInfo;
import com.appiancorp.suiteapi.type.TypeService;
import com.vass.gex.AppianBase64Utils;
import com.appiancorp.suiteapi.knowledge.Document;



@PaletteInfo(paletteCategory = PaletteCategoryConstants.INTEGRATION_SERVICES , palette = "Connectivity Services")
public class convertToDoc extends AppianSmartService{
	
	private static final Logger LOG = Logger.getLogger(convertToDoc.class);
	
	// inputs
	  
	  private String base64String;
	  private String fileFormat;
	  private Long targetFolder;
	  private String documentName;

	  // outputs
	  private Long document;
	  private String errorMessage;
	  private boolean isError;
	

	private final SmartServiceContext smartServiceCtx;
	private ContentService contentService;

	
	
	/** 
	 * constructor que recupera el contexto de appian 
	 **/
	public convertToDoc(SmartServiceContext smartServiceCtx,
			ContentService cs, TypeService ts) {
		super();
		this.smartServiceCtx = smartServiceCtx;
		this.contentService = cs;
	}
	
	
	
	@Override
	public void run() throws SmartServiceException {
		
		
				
			    
			    try 
			    {
			      
			      document = AppianBase64Utils.decodeBase64ToDocument(base64String, documentName, fileFormat,
			        targetFolder, contentService);
			      	isError = false;
				    errorMessage = "";
			            
			    } catch ( PrivilegeException | InvalidContentException | InvalidVersionException
			      | StorageLimitException | InsufficientNameUniquenessException | DuplicateUuidException | IOException e) {
			      isError = true;
			      errorMessage = e.getMessage();
			      LOG.error(e.getMessage(), e);
			    }
		
		
	}
	
	
	@Input(required = Required.ALWAYS)
	  @Name("base64String")
	  public void setBase64String(String base64String) {
	    this.base64String = base64String;
	  }
	  
	  @Input(required = Required.ALWAYS)
	  @Name("fileFormat")
	  public void setFileFormat(String fileFormat) {
	    this.fileFormat = fileFormat;
	  }

	  @Input(required = Required.ALWAYS)
	  @FolderDataType
	  @Name("targetFolder")
	  public void setTargetFolder(Long targetFolder) {
	    this.targetFolder = targetFolder;
	  }

	  @Input(required = Required.ALWAYS)
	  @Name("documentName")
	  public void setDocumentName(String documentName) {
	    this.documentName = documentName;
	  }

	  // outputs
	  @Name("document")
	  @DocumentDataType
	  public Long getDocument() {
	    return document;
	  }

	  @Name("isError")
	  public boolean isError() {
	    return isError;
	  }

	  @Name("errorMessage")
	  public String getErrorMessage() {
	    return errorMessage;
	  }
}
